@@ -1,10 +1,14 @@
 import random
 
+import pytest
+
 import tiledb
 from tests import get_schema
 from tiledb.bioimg.helpers import open_bioimg
 from tiledb.bioimg.openslide import TileDBOpenSlide
 
+from .. import ATTR_NAME
+
 
 class TestTileDBOpenSlide:
     def test(self, tmp_path):
@@ -26,3 +30,11 @@ class TestTileDBOpenSlide:
         with TileDBOpenSlide(group_path) as t:
             assert t.level_count == len(level_dimensions)
             assert t.level_dimensions == tuple(level_dimensions)
+
+        with TileDBOpenSlide(group_path, attr=ATTR_NAME) as t:
+            assert t.level_count == len(level_dimensions)
+            assert t.level_dimensions == tuple(level_dimensions)
+
+        with pytest.raises(KeyError) as e_info:
+            _ = TileDBOpenSlide(group_path, attr="test_attr_name")
+            assert "No attribute matching 'test_attr_name'" in str(e_info.value)
