@@ -3,4 +3,4 @@ WHITE_RGB = 16777215  # FFFFFF in hex
 WHITE_RGBA = 4294967295  # FFFFFFFF in hex
 
 from .types import Converters
-from .wrappers import from_bioimg
+from .wrappers import from_bioimg, to_bioimg
